@@ -1,7 +1,9 @@
+from unittest.mock import patch
+
 from click.testing import CliRunner
 import pytest
 
-from dude._commands.cli_base import dude_cli
+from dude.__main__ import dude_cli
 from dude import __version__
 from .utils import IsolatedFixtureFolder
 
@@ -41,3 +43,11 @@ def test_prints_the_correct_version():
     result = runner.invoke(dude_cli, ["--version"])
     assert f"dude, version {__version__}" in result.output
     assert result.exit_code == 0
+
+
+def test_unexpected_exceptions_are_logged():
+    runner = CliRunner()
+    with patch("dude._commands.cli_base.print_help", side_effect=RuntimeError("💥 boom 💥")):
+        result = runner.invoke(dude_cli)
+        assert "boom" in result.output
+        assert result.exit_code != 0
